diff --git a/Demo/Makefile.am b/Demo/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Demo/Makefile.am
@@ -0,0 +1,31 @@
+AM_CPPFLAGS = -I$(top_srcdir)/Include $(UFCONFIG_CFLAGS)
+LDADD = $(top_builddir)/Source/libccolamd.la
+
+EXTRA_DIST = \
+	ccolamd_example.out \
+	ccolamd_l_example.out
+
+# Disable the .out implicit pattern rule.  Prevents GNU make from
+# adding bogus dependencies for the .out files listed above.
+%.out: %
+
+check_PROGRAMS = \
+	ccolamd_example \
+	ccolamd_l_example
+
+ccolamd_example_SOURCES = ccolamd_example.c
+ccolamd_l_example_SOURCES = ccolamd_l_example.c
+
+check-local: $(check_PROGRAMS) $(check_PROGRAMS:=.out)
+	@for i in $(check_PROGRAMS); do \
+		echo "Testing $$i"; \
+		./$$i$(EXEEXT) > my_$$i.out; \
+		if diff -u $$i.out my_$$i.out; then \
+			echo "Test $$i PASSED."; \
+		else \
+			echo "Test $$i FAILED."; \
+		fi; \
+	done
+
+clean-local:
+	-$(RM) my_*.out
diff --git a/Include/Makefile.am b/Include/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Include/Makefile.am
@@ -0,0 +1,2 @@
+pkgincludedir = $(includedir)/ccolamd
+pkginclude_HEADERS = ccolamd.h
diff --git a/Makefile.am b/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Makefile.am
@@ -0,0 +1,5 @@
+SUBDIRS = Include Source Demo
+EXTRA_DIST = README.txt Doc/ChangeLog Doc/lesser.txt
+
+pkgconfigdir = $(libdir)/pkgconfig
+pkgconfig_DATA = ccolamd.pc
diff --git a/Source/Makefile.am b/Source/Makefile.am
new file mode 100644
--- /dev/null
+++ b/Source/Makefile.am
@@ -0,0 +1,18 @@
+AM_CPPFLAGS = -I$(top_builddir)/Include $(UFCONFIG_CFLAGS)
+
+CCOLAMDSRC = \
+	ccolamd.c
+
+lib_LTLIBRARIES = libccolamd.la
+noinst_LTLIBRARIES = libccolamdl.la libccolamdi.la
+
+libccolamdi_la_SOURCES = $(CCOLAMDSRC)
+libccolamdi_la_LIBADD = -lm
+
+libccolamdl_la_SOURCES = $(CCOLAMDSRC)
+libccolamdl_la_LIBADD = -lm
+libccolamdl_la_CPPFLAGS = $(AM_CPPFLAGS) -DDLONG
+
+libccolamd_la_SOURCES = ccolamd_global.c
+libccolamd_la_LIBADD = libccolamdi.la libccolamdl.la
+libccolamd_la_LDFLAGS = -no-undefined -version-info 9:3:7
diff --git a/ccolamd.pc.in b/ccolamd.pc.in
new file mode 100644
--- /dev/null
+++ b/ccolamd.pc.in
@@ -0,0 +1,12 @@
+prefix=@prefix@
+exec_prefix=@exec_prefix@
+libdir=@libdir@
+includedir=@includedir@
+
+Name: @PACKAGE_NAME@
+Description: Constrained column approximate minimum degree ordering
+Version: @PACKAGE_VERSION@
+Requires.private: ufconfig
+Libs: -L${libdir} -lccolamd
+Libs.private: -lm
+Cflags: -I${includedir}/ccolamd
diff --git a/configure.ac b/configure.ac
new file mode 100644
--- /dev/null
+++ b/configure.ac
@@ -0,0 +1,34 @@
+AC_PREREQ([2.68])
+AC_INIT([CCOLAMD],[2.7.3],[davis@cise.ufl.edu])
+AC_CONFIG_SRCDIR([Source/ccolamd_global.c])
+AC_CONFIG_HEADER([config.h])
+AM_INIT_AUTOMAKE([foreign])
+LT_INIT
+
+AC_PROG_INSTALL
+AC_PROG_CC
+
+LIBS_SAVED=$LIBS
+
+AC_CHECK_LIB([m], [sqrt])
+
+AC_CHECK_HEADERS([limits.h stdlib.h])
+
+PKG_PROG_PKG_CONFIG
+PKG_CHECK_MODULES([UFCONFIG],[ufconfig],
+	[],
+	[AC_MSG_ERROR([cannot find ufconfig])])
+
+AC_TYPE_SIZE_T
+
+AC_CHECK_FUNCS([sqrt])
+
+LIBS=$LIBS_SAVED
+
+AC_CONFIG_FILES([
+	ccolamd.pc
+	Makefile
+	Demo/Makefile
+	Include/Makefile
+	Source/Makefile])
+AC_OUTPUT
